@@ -1,7 +1,9 @@
-from typing import Callable, Dict, List, Tuple, Union
+from typing import Callable, Dict, List, Set
+
+from graia.broadcast.utilles import argument_signature
 
 from ..typing import T_Dispatcher
-from .decorater import Decorater
+from .decorator import Decorator
 
 
 class ExecTarget:
@@ -9,19 +11,21 @@ class ExecTarget:
         self,
         callable: Callable,
         inline_dispatchers: List[T_Dispatcher] = None,
-        headless_decoraters: List[Decorater] = None,
+        headless_decorators: List[Decorator] = None,
         enable_internal_access: bool = False,
     ) -> None:
         self.callable = callable
         self.inline_dispatchers = inline_dispatchers or []
-        self.headless_decoraters = headless_decoraters or []
+        self.headless_decorators = headless_decorators or []
         self.enable_internal_access = enable_internal_access
 
-        self.dispatcher_statistics = {"total": 0, "statistics": {}}
+        self.param_paths = {}
+        self.maybe_failure = set(name for name, _, _ in argument_signature(callable))
 
     callable: Callable
     inline_dispatchers: List[T_Dispatcher] = []
-    headless_decoraters: List[Decorater] = []
+    headless_decorators: List[Decorator] = []
     enable_internal_access: bool = False
 
-    dispatcher_statistics: Dict[str, Union[int, Dict]]
+    param_paths: Dict[str, List[List[T_Dispatcher]]]
+    maybe_failure: Set[str]
