@@ -1,7 +1,7 @@
 from typing import Any, List, Type
 from abc import ABCMeta, abstractmethod
 
-from graia.broadcast.entities.decorater import Decorater
+from graia.broadcast.entities.decorator import Decorator
 from ..entities.event import BaseEvent
 from ..typing import T_Dispatcher
 
@@ -9,7 +9,7 @@ from ..typing import T_Dispatcher
 class Waiter(metaclass=ABCMeta):
     listening_events: List[Type[BaseEvent]]
     using_dispatchers: List[T_Dispatcher]
-    using_decorators: List[Decorater]
+    using_decorators: List[Decorator]
     priority: int
     enable_internal_access: bool
     block_propagation: bool
@@ -19,7 +19,7 @@ class Waiter(metaclass=ABCMeta):
         cls,
         listening_events: List[Type[BaseEvent]],
         using_dispatchers: List[T_Dispatcher] = None,
-        using_decorators: List[Decorater] = None,
+        using_decorators: List[Decorator] = None,
         priority: int = 15,  # 默认情况下都是需要高于默认 16 的监听吧...
         enable_internal_access: bool = False,
         block_propagation: bool = False,
@@ -49,7 +49,7 @@ class Waiter(metaclass=ABCMeta):
         cls,
         listening_events: List[Type[BaseEvent]],
         using_dispatchers: List[T_Dispatcher] = None,
-        using_decorators: List[Decorater] = None,
+        using_decorators: List[Decorator] = None,
         priority: int = 15,  # 默认情况下都是需要高于默认 16 的监听吧...
         enable_internal_access: bool = False,
         block_propagation: bool = False,
